abacusai.annotation — AbacusAI documentation

# `abacusai.annotation`

## Module Contents

### Classes

`Annotation` | An Annotation Store Annotation

class abacusai.annotation.Annotation(client, annotationType=None, annotationValue=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An Annotation Store Annotation

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - annotationType (str) – A name determining the type of annotation and how to interpret the annotation value data, e.g. as a label, bounding box, etc.

    - annotationValue (dict) – JSON-compatible value of the annotation. The format of the value is determined by the annotation type.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict